# toil_mergevcfs

[![pypi badge][pypi_badge]][pypi_base]
[![travis badge][travis_badge]][travis_base]
[![codecov badge][codecov_badge]][codecov_base]
[![docker badge][docker_badge]][docker_base]
[![docker badge][automated_badge]][docker_base]
[![code formatting][black_badge]][black_base]

A toil tool to merge vcfs from different callers.

## Usage

This package uses docker to manage its dependencies, there are 2 ways of using it:

1. Running the [container][docker_base] in single machine mode without [`--batchSystem`] support:

        # using docker
        docker run -it leukgen/toil_mergevcfs --help

        # using singularity
        singularity run docker://leukgen/toil_mergevcfs --help

1. Installing the python package from [pypi][pypi_base] and passing the container as a flag:

        # install package
        pip install toil_mergevcfs

        # run with docker
        toil_mergevcfs [TOIL-OPTIONS] [PIPELINE-OPTIONS]
            --docker leukgen/toil_mergevcfs
            --volumes <local path> <container path>
            --batchSystem LSF \
            --vcf {path to vcf1} \
            --vcf {path to vcf2} \
            --vcf {path to vcf3} \
            --out {path to merged output vcf.gz} \
            --snv

        # run with singularity
        toil_mergevcfs [TOIL-OPTIONS] [PIPELINE-OPTIONS]
            --singularity docker://leukgen/toil_mergevcfs
            --volumes <local path> <container path>
            --batchSystem LSF \
            --vcf {path to vcf1} \
            --vcf {path to vcf2} \
            --vcf {path to vcf3} \
            --out {path to merged output vcf.gz} \
            --snv

See [docker2singularity] if you want to use a [singularity] image instead of using the `docker://` prefix.

## Options

| Option      | Description                                   |
| ----------- | --------------------------------------------- |
| --vcf       | Path to a input vcf file                      |
| --out       | Path to the output file                       |
| --snv       | If the input vcf files contain only snvs      |
| --indel     | If the input vcf files contain only indels    |
| --reference | Path to the reference fasta                   |
| --temp      | Temporary working directory                   |

## Contributing

Contributions are welcome, and they are greatly appreciated, check our [contributing guidelines](.github/CONTRIBUTING.md)!

## Credits

This package was created using [Cookiecutter] and the
[leukgen/cookiecutter-toil] project template.

<!-- References -->
[singularity]: http://singularity.lbl.gov/
[docker2singularity]: https://github.com/singularityware/docker2singularity
[cookiecutter]: https://github.com/audreyr/cookiecutter
[leukgen/cookiecutter-toil]: https://github.com/leukgen/cookiecutter-toil
[`--batchSystem`]: http://toil.readthedocs.io/en/latest/developingWorkflows/batchSystem.html?highlight=BatchSystem

<!-- Badges -->
[docker_base]: https://hub.docker.com/r/leukgen/toil_mergevcfs
[docker_badge]: https://img.shields.io/docker/build/leukgen/toil_mergevcfs.svg
[automated_badge]: https://img.shields.io/docker/automated/leukgen/toil_mergevcfs.svg
[codecov_badge]: https://codecov.io/gh/leukgen/toil_mergevcfs/branch/master/graph/badge.svg
[codecov_base]: https://codecov.io/gh/leukgen/toil_mergevcfs
[pypi_badge]: https://img.shields.io/pypi/v/toil_mergevcfs.svg
[pypi_base]: https://pypi.python.org/pypi/toil_mergevcfs
[travis_badge]: https://img.shields.io/travis/leukgen/toil_mergevcfs.svg
[travis_base]: https://travis-ci.org/leukgen/toil_mergevcfs
[black_badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black_base]: https://github.com/ambv/black
