"""toil_mergevcfs utils tests."""
from os.path import join
import gzip
import shutil

from toil_mergevcfs import utils
from tests.utils import TEST


def test_rename_samples_headers(tmpdir):
    """Test the util to rename the columns samples with the callers name."""
    tmp_in_1 = join(str(tmpdir), "tmp1.in")
    tmp_in_2 = join(str(tmpdir), "tmp2.in")
    tmp_out_1 = join(str(tmpdir), "tmp1.out")
    tmp_out_2 = join(str(tmpdir), "tmp2.out")

    in_vcf_1 = TEST["strelka_snvs"]
    in_vcf_2 = TEST["strelka_gm_snvs"]
    shutil.copyfile(in_vcf_1, tmp_in_1)
    shutil.copyfile(in_vcf_2, tmp_in_2)

    utils.rename_samples_headers(tmp_in_1, tmp_out_1)
    utils.rename_samples_headers(tmp_in_2, tmp_out_2)

    expected_header_1 = (
        "#CHROM\tPOS\tID\tREF\tALT\tQUAL\tFILTER\tINFO\tFORMAT\t"
        "strelka_NORMAL\tstrelka_TUMOR\n"
    )
    expected_header_2 = (
        "#CHROM\tPOS\tID\tREF\tALT\tQUAL\tFILTER\tINFO\tFORMAT\tstrelka_NORMAL\n"
    )

    with gzip.open(tmp_out_1 + ".gz", "r") as fin:
        content = fin.read()
        assert expected_header_1 in content
    with gzip.open(tmp_out_2 + ".gz", "r") as fin:
        content = fin.read()
        assert expected_header_2 in content
